# ==============================================================================
# THUNAR SPECIFIC SETTINGS
# ==============================================================================

style "sidepane" {
	GtkTreeView::odd_row_color = @sidebar_bg
  	GtkTreeView::even_row_color = @sidebar_bg
	base[NORMAL] 		= @bg_color
	base[INSENSITIVE] 	= mix(0.4, shade(1.35, @selected_bg_color), shade(0.9, @base_color))
	bg[NORMAL] 			= @bg_color
	text[NORMAL] 		= mix(0.9, @sidebar_fg, @sidebar_fg)
}

style "thunar-frame" {
  xthickness = 0
  ythickness = 0
}

style "thunar-handle" { GtkPaned::handle-size = 2 }

widget_class "*ThunarWindow*.<GtkScrolledWindow>"       style "thunar-frame"
widget_class "*ThunarWindow*.<GtkHPaned>"               style "thunar-handle"
widget_class "*ThunarShortcutsView*" style "sidepane"
widget_class "*ThunarTreeView*" style "sidepane"
