STATE_PATH = ".config/looks-install"

DESK_THEME_PATH = {
    "gnome": {
        "themes": {
            "local": "~/.local/share/themes",
            "global": "/usr/share/themes",
        },
        "icons": {
            "local": "~/.local/share/icons",
            "global": "/usr/share/icons",
        },
        "cursors": {
            "local": "~/.local/share/icons",
            "global": "/usr/share/icons",
        },
    },
    "kde": {
        "themes": {
            "local": "~/.local/share/plasma/desktoptheme",
            "global": "/usr/share/plasma/desktoptheme",
        },
        "global_theme": {
            "local": "~/.local/share/plasma/look-and-feel",
            "global": "/usr/share/plasma/look-and-feel",
        },
        "icons": {
            "local": "~/.local/share/icons",
            "global": "/usr/share/icons",
        },
        "cursors": {
            "local": "~/.icons",
            "global": "/usr/share/icons",
        },
    },
    "xfce": {
        "themes": {
            "local": "~/.themes",
            "global": "/usr/share/themes",
        },
        "icons": {
            "local": "~/.icons",
            "global": "/usr/share/icons",
        },
        "cursors": {
            "local": "~/.icons",
            "global": "/usr/share/icons",
        },
    },
}
